---
{%- from "haproxy/map.jinja" import haproxy with context %}
haproxy-pkg:
  pkg.installed:
    - pkgs: {{ haproxy.pkgs }}
    - watch_in:
      - service: haproxy-service

haproxy-config-dir:
  file.directory:
    - name: {{ haproxy.config.dir }}
    - user: {{ haproxy.config.user }}
    - group: {{ haproxy.config.group }}
    - mode: "0700"
    - recurse:
      - user
      - group

{% for dir in haproxy.config.dirs %}
haproxy-config-{{ dir }}-dir:
  file.directory:
    - name: {{ haproxy.config.dir }}/{{ dir }}
    - user: {{ haproxy.config.user }}
    - group: {{ haproxy.config.group }}
    - mode: "0700"
{% endfor %}

{% for file in haproxy.config.scripts %}
haproxy-script-{{ file.name }}:
  file.managed:
    - name: {{ haproxy.config.dir }}/{{ file.name }}
    - source: salt://haproxy/{{ file.name }}
    - user: {{ haproxy.config.user }}
    - group: {{ haproxy.config.group }}
    - mode: "0600"
    - watch_in:
      - service: haproxy-service
{% endfor %}

{% for file in haproxy.config.geoip.dbs %}
haproxy-geoip-{{ file.name }}:
  file.managed:
    - name: {{ file.name }}
    - source: {{ file.url }}
    - skip_verify: True
    - makedirs: True
    - user: {{ haproxy.config.user }}
    - group: {{ haproxy.config.group }}
    - mode: "0600"
    - watch_in:
      - service: haproxy-service
{% endfor %}

haproxy-hatop-download:
  file.managed:
    - name: /usr/bin/hatop
    - source: {{ haproxy.hatop.fetchurl }}/v{{ haproxy.hatop.version }}/hatop
    - source_hash: {{ haproxy.hatop.hash }}
    - user: root
    - group: root
    - mode: "0755"
